/*-------------------------------------------------------------------------+
| Copyright 2019 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.common.ui.javafx.util;

import java.io.IOException;
import java.net.URL;

import javafx.fxml.FXML;
import javafx.fxml.FXMLLoader;

/**
 * Utility methods for handling {@link FXML} layouts.
 * 
 * @author munaro
 */
// TODO(AD): Please rename to JFXUtils or JavaFXUtils. Please unify with SceneGraphUtils.
public class FXMLUtils {

	/**
	 * Loads a JavaFX layout from an {@link FXML} resource and associates it with the given
	 * controller.
	 * 
	 * @param fxmlResource
	 *            {@link URL} of the {@link FXML} resource to load.
	 * @param controller
	 *            Controller to be added to associated with the returned scene.
	 * @return The loaded object hierarchy. See {@link FXMLLoader} for more information.
	 * @throws IOException
	 */
	public static <T> T load(URL fxmlResource, Object controller) throws IOException {
		FXMLLoader fxmlLoader = new FXMLLoader();
		fxmlLoader.setClassLoader(controller.getClass().getClassLoader());
		fxmlLoader.setController(controller);
		fxmlLoader.setLocation(fxmlResource);

		return fxmlLoader.load();
	}
}
